@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Configuration file core loading functions
 """
-
-# Import python libs
-import os
 import glob
-import fnmatch
+import os
+
 import dict_tools.update
 
 
