@@ -2,8 +2,6 @@
 The os sub is used to gather configuration options from the OS facility
 to send configuration options into applications.
 """
-# Import python libs
-import os
 
 
 def gather(hub, raw):
