@@ -21,7 +21,8 @@ def setup(hub, conf):
     ch.setFormatter(cf)
     root.addHandler(ch)
 
-    ff = logging.Formatter(fmt=conf["log_fmt_console"], datefmt=conf["log_datefmt"])
+    ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
     fh = logging.FileHandler(conf["log_file"])
+    fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
